====================================
Linear algebra (:mod:`scipy.linalg`)
====================================

.. module:: scipy.linalg

Basics
======

.. autosummary::
   :toctree: generated/

   inv
   solve
   solve_banded
   solveh_banded
   solve_triangular
   det
   norm
   lstsq
   pinv
   pinv2

Eigenvalue Problem
==================

.. autosummary::
   :toctree: generated/

   eig
   eigvals
   eigh
   eigvalsh
   eig_banded
   eigvals_banded

Decompositions
==============

.. autosummary::
   :toctree: generated/

   lu
   lu_factor
   lu_solve
   svd
   svdvals
   diagsvd
   orth
   cholesky
   cholesky_banded
   cho_factor
   cho_solve
   cho_solve_banded
   qr
   schur
   rsf2csf
   hessenberg

Matrix Functions
================

.. autosummary::
   :toctree: generated/

   expm
   expm2
   expm3
   logm
   cosm
   sinm
   tanm
   coshm
   sinhm
   tanhm
   signm
   sqrtm
   funm

Special Matrices
================

.. autosummary::
   :toctree: generated/

   block_diag
   circulant
   companion
   hadamard
   hankel
   kron
   leslie
   toeplitz
   tri
   tril
   triu
